@@ -1,10 +1,9 @@
 from functools import wraps
 from rest_framework.decorators import api_view
-from django.core.exceptions import PermissionDenied
 from django.http import HttpResponseServerError
 from django.conf import settings
 from importlib import import_module
-import proxy_server
+import proxy_server, json
 
 def expose_service(methods, public=False):
     def decorator(view_func):
@@ -27,6 +26,7 @@ def expose_service(methods, public=False):
                                 try:
                                     response = val_func(request)
                                 except Exception as e:
+                                    print 'ERROR: ',e
                                     error_message = 'Could not invoke token validation service'
                                     raise Exception
 
@@ -51,9 +51,19 @@ def expose_service(methods, public=False):
                 if error_message is None:
                     if e.message is not None:
                         error_message = e.message
+
                     else:
                         error_message = 'Server encountered an error and cannot proceed with service call'
-                return HttpResponseServerError(error_message)
+
+                error = {
+                    'error': {
+                        'code': 500,
+                        'type': 'ProxyServerError',
+                        'message': error_message
+                    }
+                }
+
+                return HttpResponseServerError(json.dumps(error), content_type='application/json')
 
         return wraps(view_func)(wrapper)
     return decorator
