@@ -16,6 +16,6 @@ def test_error(request):
     return invoke_backend_service_as_proxy(request, 'POST', service_url, json_data={ 'email':'admin@test.com' })
 
 @expose_service(['GET'])
-def test_token_validation(request):
+def test_token_validation(request, public=True):
     service_url = generate_service_url('/login')
     return invoke_backend_service_as_proxy(request, 'POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' })
